@@ -20,75 +20,66 @@
 
 #include "klinkstatus.h"
 
-#include <kapplication.h>
+#include <kuniqueapplication.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <kdebug.h>
 
-#include <iostream>
-using namespace std;
-
 
 static const char description[] =
     I18N_NOOP("A Link Checker.\n\nKLinkStatus belongs to the kdewebdev module from KDE.");
 
-static const char version[] = "0.3.2";
-
-static KCmdLineOptions options[] =
-    {
-        { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
-        KCmdLineLastOption
-    };
+static const char version[] = "0.5.1";
 
 int main(int argc, char *argv[])
 {
-    //____________________________________________________
-    
-    KAboutData about("klinkstatus", I18N_NOOP("KLinkStatus"), version, description,
-                     KAboutData::License_GPL_V2, "(C) 2004 Paulo Moura Guedes", 0,
+    KAboutData about("klinkstatus", 0, ki18n("KLinkStatus"), version, ki18n(description),
+                     KAboutData::License_GPL_V2, ki18n("(C) 2004-2007 Paulo Moura Guedes"), KLocalizedString(),
                      "http://klinkstatus.kdewebdev.org");
 
-    about.addAuthor("Paulo Moura Guedes", 0, "moura@kdewebdev.org");
+    about.addAuthor(ki18n("Paulo Moura Guedes"), KLocalizedString(), "moura@kdewebdev.org");
 
-    about.addCredit("Manuel Menezes de Sequeira", 0, 0, "http://home.iscte.pt/~mms/");
-    about.addCredit("Gonçalo Silva", 0, "gngs@paradigma.co.pt");
-    about.addCredit("Nuno Monteiro", 0, 0, "http://www.itsari.org");
-    about.addCredit("Eric Laffoon", 0, "sequitur@kde.org");
-    about.addCredit("Andras Mantia", 0, "amantia@kde.org");
-    about.addCredit("Michal Rudolf", 0, "mrudolf@kdewebdev.org");
-    about.addCredit("Mathieu Kooiman", 0, " quanta@map-is.nl");
-    about.addCredit("Jens Herden", 0, "jens@kdewebdev.org");
-    about.addCredit("Helge Hielscher", 0, "hhielscher@unternehmen.com");
+    about.addCredit(ki18n("Manuel Menezes de Sequeira"), KLocalizedString(), 0, "http://home.iscte.pt/~mms/");
+    about.addCredit(ki18n("Gonçalo Silva"), KLocalizedString(), "http://paradigma.pt/gngs/");
+    about.addCredit(ki18n("Nuno Monteiro"), KLocalizedString(), 0, "http://www.itsari.org");
+    about.addCredit(ki18n("Eric Laffoon"), KLocalizedString(), "sequitur@kde.org");
+    about.addCredit(ki18n("Andras Mantia"), KLocalizedString(), "amantia@kde.org");
+    about.addCredit(ki18n("Michal Rudolf"), KLocalizedString(), "mrudolf@kdewebdev.org");
+    about.addCredit(ki18n("Mathieu Kooiman"), KLocalizedString(), " quanta@map-is.nl");
+    about.addCredit(ki18n("Jens Herden"), KLocalizedString(), "jens@kdewebdev.org");
+    about.addCredit(ki18n("Helge Hielscher"), KLocalizedString(), "hhielscher@unternehmen.com");
 
     KCmdLineArgs::init(argc, argv, &about);
-    KCmdLineArgs::addCmdLineOptions( options );
 
-    KApplication app;
+    KCmdLineOptions options;
+    options.add("+[URL]", ki18n("Document to open"));
+    KCmdLineArgs::addCmdLineOptions(options);
+    
+    KUniqueApplication app;
 
     // see if we are starting with session management
-    if (app.isRestored())
+    if (app.isSessionRestored())
     {
         RESTORE(KLinkStatus);
     }
     else
     {
         // no session.. just start up normally
-        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+        KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
 
-        KLinkStatus *widget = new KLinkStatus;
+        KLinkStatus *widget = new KLinkStatus;        
         widget->show();
 
         if ( args->count() == 0 )
         {
-            widget->load(KURL());
+            widget->load(KUrl());
         }
         else
         {
-            int i = 0;
-            for (; i < args->count(); i++ )
+            for(int i = 0; i != args->count(); ++i)
             {
-                widget->load( args->url( i ) );
+                widget->load(args->url(i));
             }
         }
         args->clear();
