@@ -1,20 +1,24 @@
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2002 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
-/***************************************************************************
-                          file_cmds.c  -  define file command related functions
-                             -------------------
-    begin                : Sat Jan 19 2002
-    copyright            : (C) 2002 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 
 #include <stdio.h>
 #include <libxml/tree.h>
@@ -29,16 +33,7 @@
 
 static char buffer[500];
 
-/**
- * xslDbgEntities:
- * 
- * Print list of entites found 
- *
- * Returns 1 on sucess,
- *         0 otherwise
- */
-int
-xslDbgEntities(void)
+int xslDbgEntities(void)
 {
     int result = 0;
 
@@ -68,7 +63,7 @@ xslDbgEntities(void)
                                                        entityIndex);
                 if (entInfo) {
 		    /* display identifier of an XML entity */
-                    xsldbgGenericErrorFunc(i18n("Entity %1 ").arg(xsldbgText(entInfo->SystemID)));
+                    xsldbgGenericErrorFunc(i18n("Entity %1 ", xsldbgText(entInfo->SystemID)));
                     if (entInfo->PublicID)
 			xsldbgGenericErrorFunc(xsldbgText(entInfo->PublicID));
 		    xsldbgGenericErrorFunc("\n");
@@ -77,7 +72,7 @@ xslDbgEntities(void)
             if (arrayListCount(filesEntityList()) == 0) {
                 xsldbgGenericErrorFunc(i18n("No external General Parsed entities present.\n"));
             } else {
-		xsldbgGenericErrorFunc(i18n("\tTotal of %n entity found.", "\tTotal of %n entities found.", arrayListCount(filesEntityList())) + QString("\n"));
+		xsldbgGenericErrorFunc(i18np("\tTotal of %1 entity found.", "\tTotal of %1 entities found.", arrayListCount(filesEntityList())) + QString("\n"));
             }
 
             result = 1;
@@ -87,17 +82,7 @@ xslDbgEntities(void)
 }
 
 
-/**
- * xslDbgSystem:
- * @arg : Is valid
- * 
- * Print what a system file @arg maps to via the current xml catalog
- *
- * Returns 1 on sucess,
- *         0 otherwise
- */
-int
-xslDbgSystem(const xmlChar * arg)
+int xslDbgSystem(const xmlChar * arg)
 {
     int result = 0;
     xmlChar *name;
@@ -118,15 +103,15 @@ xslDbgSystem(const xmlChar * arg)
             xmlFree(name);
         } else {
             notifyXsldbgApp(XSLDBG_MSG_RESOLVE_CHANGE, "");
-            xsldbgGenericErrorFunc(i18n("SystemID \"%1\" was not found in current catalog.\n").arg(xsldbgText(arg)));
+            xsldbgGenericErrorFunc(i18n("SystemID \"%1\" was not found in current catalog.\n", xsldbgText(arg)));
         }
     } else {
         if (name) {
-            xsldbgGenericErrorFunc(i18n("SystemID \"%1\" maps to: \"%2\"\n").arg(xsldbgText(arg)).arg(xsldbgText(name)));
+            xsldbgGenericErrorFunc(i18n("SystemID \"%1\" maps to: \"%2\"\n", xsldbgText(arg), xsldbgText(name)));
             xmlFree(name);
             result = 1;
         } else {
-            xsldbgGenericErrorFunc(i18n("SystemID \"%1\" was not found in current catalog.\n").arg(xsldbgText(arg)));
+            xsldbgGenericErrorFunc(i18n("SystemID \"%1\" was not found in current catalog.\n", xsldbgText(arg)));
         }
     }
 
@@ -134,17 +119,7 @@ xslDbgSystem(const xmlChar * arg)
 }
 
 
-/**
- * xslDbgPublic:
- * @arg : Is valid
- * 
- * Print what a public ID @arg maps to via the current xml catalog
- *
- * Returns 1 on sucess,
- *         0 otherwise
- */
-int
-xslDbgPublic(const xmlChar * arg)
+int xslDbgPublic(const xmlChar * arg)
 {
     int result = 0;
     xmlChar *name;
@@ -165,33 +140,23 @@ xslDbgPublic(const xmlChar * arg)
             xmlFree(name);
         } else {
             notifyXsldbgApp(XSLDBG_MSG_RESOLVE_CHANGE, "");
-	    xsldbgGenericErrorFunc(i18n("PublicID \"%1\" was not found in current catalog.\n").arg(xsldbgText(arg)));
+	    xsldbgGenericErrorFunc(i18n("PublicID \"%1\" was not found in current catalog.\n", xsldbgText(arg)));
         }
     } else {
         if (name) {
-            xsldbgGenericErrorFunc(i18n("PublicID \"%1\" maps to: \"%2\"\n").arg(xsldbgText(arg)).arg(xsldbgText(name)));
+            xsldbgGenericErrorFunc(i18n("PublicID \"%1\" maps to: \"%2\"\n", xsldbgText(arg), xsldbgText(name)));
             xmlFree(name);
             result = 1;
         } else {
-	    xsldbgGenericErrorFunc(i18n("PublicID \"%1\" was not found in current catalog.\n").arg(xsldbgText(arg)));
+	    xsldbgGenericErrorFunc(i18n("PublicID \"%1\" was not found in current catalog.\n", xsldbgText(arg)));
         }
-        xsltGenericError(xsltGenericErrorContext, buffer);
+        xsltGenericError(xsltGenericErrorContext, "%s", buffer);
     }
     return result;
 }
 
 
-/**
- * xslDbgEncoding:
- * @arg: Is valid encoding supported by libxml2
- *
- * Set current encoding to use for output to standard output
- *
- * Returns 1 on sucess,
- *         0 otherwise
- */
-int
-xslDbgEncoding(xmlChar * arg)
+int xslDbgEncoding(xmlChar * arg)
 {
     int result = 0;
     xmlChar *opts[2];
@@ -206,35 +171,24 @@ xslDbgEncoding(xmlChar * arg)
 
     if (splitString(arg, 1, opts) == 1) {
         if (filesSetEncoding((char *) opts[0])) {
-            optionsSetStringOption(OPTIONS_ENCODING, opts[0]);
+            optionsSetStringOption(OPTIONS_ENCODING, xsldbgText(opts[0]));
             result = 1;
         }
     } else
-        xsldbgGenericErrorFunc(i18n("Error: Missing arguments for the command %1.\n").arg("encoding"));
+        xsldbgGenericErrorFunc(i18n("Error: Missing arguments for the command %1.\n", QString("encoding")));
     return result;
 }
 
 
-/**
- * xslDbgShellOutput:
- * @arg : Is valid, either a local file name which will be expanded 
- *        if needed, or a "file://" protocol URI
- *
- * Set the output file name to use
- *
- * Returns 1 on success, 
- *         0 otherwise
- */
 int xslDbgShellOutput(const xmlChar *arg)
 {
   int result = 0;
   if (arg && (xmlStrLen(arg) > 0)){
-     if (!xmlStrnCmp(arg, "file://", 7)){
+     if (!xmlStrnCmp(arg, "file:/", 6)){
       /* convert URI to local file name */
       xmlChar *outputFileName = filesURItoFileName(arg);
       if (outputFileName){
-	optionsSetStringOption(OPTIONS_OUTPUT_FILE_NAME,
-				     outputFileName);
+	optionsSetStringOption(OPTIONS_OUTPUT_FILE_NAME, xsldbgText(outputFileName));
 	notifyXsldbgApp(XSLDBG_MSG_FILE_CHANGED, 0L);
 	xmlFree(outputFileName);
 	result = 1;
@@ -245,28 +199,27 @@ int xslDbgShellOutput(const xmlChar *arg)
       notifyXsldbgApp(XSLDBG_MSG_FILE_CHANGED, 0L);
       result = 1;
     } else if (!xmlStrnCmp(arg, "ftp://", 6) || !xmlStrnCmp(arg, "http://", 7)){
-	xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").arg("output"));
+	xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n", QString("output")));
 	return 0;
     } else {
       /* assume that we were provided a local file name
        * that may need expanding 
        */
-      xmlChar *expandedName = filesExpandName(arg);
+      QString expandedName = filesExpandName(xsldbgText(arg));
      
       // The output file must not be the same as our SOURCE or DATA file
-      if (expandedName && 
-	(!xmlStrEqual(optionsGetStringOption(OPTIONS_SOURCE_FILE_NAME), expandedName)) &&
-	(!xmlStrEqual(optionsGetStringOption(OPTIONS_DATA_FILE_NAME), expandedName)) ){
+      if (!expandedName.isEmpty() &&
+	(optionsGetStringOption(OPTIONS_SOURCE_FILE_NAME) !=  expandedName) &&
+	(optionsGetStringOption(OPTIONS_DATA_FILE_NAME) != expandedName) ){
 	   optionsSetStringOption(OPTIONS_OUTPUT_FILE_NAME, expandedName);
 	   notifyXsldbgApp(XSLDBG_MSG_FILE_CHANGED, 0L);
-	   xmlFree(expandedName);
 	   result = 1;
       }else{
-	   xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").arg("output"));
+	   xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n", QString("output")));
       }
     }
    } else {
-    xsldbgGenericErrorFunc(i18n("Error: Missing arguments for the command %1.\n").arg("output"));
+    xsldbgGenericErrorFunc(i18n("Error: Missing arguments for the command %1.\n", QString("output")));
   }
 
   return result;
